colors = {
    "catppuccin" : {
        "colorOne": "#F28FAD",
        "colorTwo": "#DDB6F2",
        "colorThree": "#96CDFB",
        "colorFour": "#ABE9B3",
        "colorFive": "#F8BD96",
        "colorSix": "#FAE3B0",
        "fg": "#D9E0EE",
    },
    "dracula" : {
        "colorOne": "#ff5555",
        "colorTwo": "#bd93f9",
        "colorThree": "#8be9fd",
        "colorFour": "#50fa7b",
        "colorFive": "#ffb86c",
        "colorSix": "#f1fa8c",
        "fg": "#f8f8f2",
    },
    "nord" : {
        "colorOne": "#BF616A",
        "colorTwo": "#B48EAD",
        "colorThree": "#88C0D0",
        "colorFour": "#A3BE8C",
        "colorFive": "#D08770",
        "colorSix": "#EBCB8B",
        "fg": "#ECEFF4",
    },
    "gruvbox" : {
        "colorOne": "#FB4934",
        "colorTwo": "#D3869B",
        "colorThree": "#83A598",
        "colorFour": "#B8BB26",
        "colorFive": "#FE8019",
        "colorSix": "#FABD2F",
        "fg": "#EBDBB2",
    },
    "onedark" : {
        "colorOne": "#E06C75",
        "colorTwo": "#C678DD",
        "colorThree": "#61AFEF",
        "colorFour": "#98C379",
        "colorFive": "#D19A66",
        "colorSix": "#E5C07B",
        "fg": "#ABB2BF",
    },
    "tokyonight" : {
        "colorOne": "#F7768E",
        "colorTwo": "#ad8ee6",
        "colorThree": "#7AA2F7",
        "colorFour": "#9ECE6A",
        "colorFive": "#FF9E64",
        "colorSix": "#E0AF68",
        "fg": "#a9b1d6",
    },
    "rosepine" : {
        "colorOne": "#eb6f92",
        "colorTwo": "#c4a7e7",
        "colorThree": "#9ccfd8",
        "colorFour": "#31748f",
        "colorFive": "#ebbcba",
        "colorSix": "#f6c177",
        "fg": "#e0def4",
    },
    "ayu" : {
        "colorOne": "#ff3333",
        "colorTwo": "#d4bfff",
        "colorThree": "#73d0ff",
        "colorFour": "#bae67e",
        "colorFive": "#ffa759",
        "colorSix": "#ffee99",
        "fg": "#cbccc6",
    },
    "palenight" : {
        "colorOne": "#ff5572",
        "colorTwo": "#c792ea",
        "colorThree": "#60adec",
        "colorFour": "#c3e88d",
        "colorFive": "#f07178",
        "colorSix": "#ffcb6b",
        "fg": "#fffefe",
    },
    "gogh" : {
        "colorOne": "#ff5572",
        "colorTwo": "#f580ff",
        "colorThree": "#75a1ff",
        "colorFour": "#62de84",
        "colorFive": "#f07178",
        "colorSix": "#ffcb6b",
        "fg": "#fffefe",
    }
}
